<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>DetailView</name>
    <message>
        <location filename="../package/contents/ui/DetailView.qml" line="14"/>
        <source>Copy value</source>
        <translation>Wert kopieren</translation>
    </message>
</context>
<context>
    <name>DevicesPage</name>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
        <source>Resume</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
        <location filename="../package/contents/ui/DevicesPage.qml" line="116"/>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="102"/>
        <source>Copy name</source>
        <translation>Namen kopieren</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="107"/>
        <source>Copy ID</source>
        <translation>ID kopieren</translation>
    </message>
</context>
<context>
    <name>DirectoriesPage</name>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="20"/>
        <source>Filter directories</source>
        <translation>Verzeichnisse filtern</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="81"/>
        <source>Show errors</source>
        <translation>Zeige Fehler</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="92"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="161"/>
        <source>Rescan</source>
        <translation>Scannen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="100"/>
        <source>Resume</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="100"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="168"/>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="110"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="175"/>
        <source>Open in file browser</source>
        <translation>Im Dateibrowser öffnen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="147"/>
        <source>Copy label/ID</source>
        <translation>Namen/ID kopieren</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="152"/>
        <source>Copy path</source>
        <translation>Pfad kopieren</translation>
    </message>
</context>
<context>
    <name>DownloadsPage</name>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="66"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="122"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="147"/>
        <source>Open in file browser</source>
        <translation>Im Dateibrowser öffnen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="138"/>
        <source>Copy label/ID</source>
        <translation>Namen/ID kopieren</translation>
    </message>
</context>
<context>
    <name>FullRepresentation</name>
    <message>
        <source>Connect</source>
        <translation type="vanished">Verbinden</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation type="vanished">Fortsetzen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="vanished">Pausieren</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="vanished">Stoppen</translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="vanished">Starten</translation>
    </message>
    <message>
        <source>Show new notifications</source>
        <translation type="vanished">Neue Benachrichtigungen anzeigen</translation>
    </message>
    <message>
        <source>Show own device ID</source>
        <translation type="vanished">Eigene Geräte-ID anzeigen</translation>
    </message>
    <message>
        <source>Show Syncthing log</source>
        <translation type="vanished">Syncthing-Log anzeigen</translation>
    </message>
    <message>
        <source>Rescan all directories</source>
        <translation type="vanished">Alle Verzeichnisse neu scannen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Einstellungen</translation>
    </message>
    <message>
        <source>Open Syncthing</source>
        <translation type="vanished">Syncthing öffnen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="241"/>
        <source>Global</source>
        <translation>Globale</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="248"/>
        <source>Global incoming traffic</source>
        <translation>Globaler eingehender Datenverkehr</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="266"/>
        <source>Local</source>
        <translation>Lokale</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="273"/>
        <source>Global outgoing traffic</source>
        <translation>Globaler ausgehender Datenverkehr</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="29"/>
        <source>Directories</source>
        <translation>Verzeichnisse</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="35"/>
        <source>Devices</source>
        <translation>Geräte</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="41"/>
        <source>Downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="47"/>
        <source>History</source>
        <translatorcomment>&quot;Letzte Änderungen&quot; is too long</translatorcomment>
        <translation>Änderungen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="99"/>
        <source>Toggle filter</source>
        <translation>Filter ein-/ausblenden</translation>
    </message>
    <message>
        <source>About Syncthing Tray</source>
        <translation type="vanished">Über Syncthing Tray</translation>
    </message>
</context>
<context>
    <name>Plasmoid::AppearanceOptionPage</name>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="6"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
        <source>Size of directory/device/download list</source>
        <translation>Größe der Verzeichnis-/Geräte-/Downloadliste</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="64"/>
        <source> x </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="90"/>
        <source> grid units</source>
        <translation> Rastereinheiten</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="108"/>
        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop or in full screen mode. When displayed as entry of the system tray Plasmoid the size can not be changed (setting a high value just leads to the contents being clipped).</source>
        <translation>Die Größe wird ignoriert when das Plasmoid auf dem Desktop oder im Vollbildmodus dargestellt wird. Wenn das Plasmoid innerhalb des Systemtray-Plasmoids dargestellt wird kann die Größe nicht geändert werden (einen größeren Wert einzustellen führt nur dazu, dass der Inhalt abgeschnitten wird).</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="120"/>
        <source>States to enable passive mode</source>
        <translatorcomment>Plural: https://www.duden.de/rechtschreibung/Status</translatorcomment>
        <translation>Status für passiven Modus</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation type="vanished">Farben</translation>
    </message>
    <message>
        <source>Bright custom text colors (use for dark color scheme)</source>
        <translation type="vanished">Helle benutzerdefinierte Schriftfarben (für dunkles Farbschema gedacht)</translation>
    </message>
</context>
<context>
    <name>Plasmoid::Settings</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="29"/>
        <source>The settings on this page are specific to the current instance of the Plasmoid.</source>
        <translation>Die Einstellungen auf dieser Seite sind spezifisch für die aktuelle Instanz des Plasmoids.</translation>
    </message>
</context>
<context>
    <name>Plasmoid::SettingsDialog</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="124"/>
        <source>Plasmoid</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="132"/>
        <source>Web view</source>
        <translation>Weboberfläche</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="138"/>
        <source>Extras</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Plasmoid::ShortcutOptionPage</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="66"/>
        <source>Shortcuts</source>
        <translation>Kurzbefehle</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="72"/>
        <source>Global shortcut</source>
        <translation>Globales Tastenkürzel</translation>
    </message>
</context>
<context>
    <name>Plasmoid::SyncthingApplet</name>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="379"/>
        <source>About</source>
        <translation>Über Syncthing Plasmoid</translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="391"/>
        <source>New notifications</source>
        <translation>Neue Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="548"/>
        <source>D-Bus error - unable to </source>
        <translation>D-Bus-Fehler bei Aktion </translation>
    </message>
</context>
<context>
    <name>RecentChangesPage</name>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="109"/>
        <source>Copy path</source>
        <translation>Pfad kopieren</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="114"/>
        <source>Copy device ID</source>
        <translation>Geräte-ID kopieren</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="119"/>
        <source>Copy directory ID</source>
        <translation>Verzeichnis-ID kopieren</translation>
    </message>
</context>
<context>
    <name>StatisticsView</name>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="12"/>
        <source> files</source>
        <translation> Dateien</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="17"/>
        <source> directories</source>
        <translation> Verzeichnisse</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="23"/>
        <source> size</source>
        <translation> Datengröße</translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="25"/>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="41"/>
        <source>Resume</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="50"/>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="99"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="113"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="169"/>
        <source>Show new notifications</source>
        <translation>Neue Benachrichtigungen anzeigen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="188"/>
        <source>About Syncthing Tray</source>
        <translation>Über Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="200"/>
        <source>Show own device ID</source>
        <translation>Eigene Geräte-ID anzeigen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="216"/>
        <source>Show Syncthing log</source>
        <translation>Syncthing-Log anzeigen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="228"/>
        <source>Rescan all directories</source>
        <translation>Alle Verzeichnisse neu scannen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="244"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/ToolBar.qml" line="259"/>
        <source>Open Syncthing</source>
        <translation>Syncthing öffnen</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Web UI</source>
        <translation type="vanished">Weboberfläche</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="59"/>
        <source>Open Syncthing</source>
        <translation>Syncthing öffnen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="60"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="63"/>
        <source>Show own device ID</source>
        <translation>Eigene Geräte-ID anzeigen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="67"/>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="68"/>
        <source>Internal errors</source>
        <translation>Interne Fehler</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="61"/>
        <source>Rescan all directories</source>
        <translation>Alle Verzeichnisse neu scannen</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="65"/>
        <source>Restart Syncthing</source>
        <translation>Syncthing neustarten</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="70"/>
        <source>About</source>
        <translation>Über Syncthing Plasmoid</translation>
    </message>
</context>
</TS>
